#
# spec file for package rssguard
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rssguard
Version:        3.3.7
Release:        1.1
Summary:        RSS/ATOM/RDF feed reader
License:        GPL-3.0
Group:          Productivity/Networking/News/Utilities
Url:            https://github.com/martinrotter/rssguard
Source0:        https://github.com/martinrotter/rssguard/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.changes
Source2:        %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM rssguard-locale.patch (gh#martinrotter/rssguard#75)
Patch0:         %{name}-locale.patch
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core) >= 5.6
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5WebEngine)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
Recommends:     %{name}-lang = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
RSS Guard is a RSS/ATOM feed aggregator developed using the Qt framework.
It supports online feed synchronization.

%lang_package

%prep
%setup -q
# let's make %%find_lang happy
%patch0 -p1
for file in localization/*.ts; do mv -v -- "${file}" "${file/-/_}"; done

# Remove build time references so build-compare can do its work
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{SOURCE1} '+%%H:%%M')
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{SOURCE1} '+%%b %%e %%Y')
sed -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" -i src/gui/dialogs/formabout.cpp
sed -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -i src/gui/dialogs/formabout.cpp

dos2unix resources/desktop/rssguard.desktop.autostart
chmod -x resources/desktop/rssguard.desktop.autostart resources/text/CHANGELOG

%build
%qmake5 LRELEASE_EXECUTABLE=lrelease-qt5 PREFIX=%{_prefix} USE_WEBENGINE=True
%make_jobs

%install
%qmake5_install
%find_lang %{name} --all-name --with-qt --without-mo
%fdupes -s %{buildroot}

%files
%defattr(-,root,root,-)
%dir %{_datadir}/%{name}
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/rssguard.png
%{_datadir}/%{name}/autostart
%{_datadir}/%{name}/icons
%{_datadir}/%{name}/information
%{_datadir}/%{name}/initial_feeds
%{_datadir}/%{name}/misc
%{_datadir}/%{name}/skins

%files lang -f %{name}.lang
%defattr(-,root,root)
%dir %{_datadir}/%{name}/lang

%changelog
* Tue Jan 24 2017 jengelh@inai.de
- Update for description guidelines.
* Tue Jan 24 2017 aloisio@gmx.com
- Update to version 3.3.7
  Added:
  * Some localizations added & updated.
  * User now can place custom user skins in user "data"
    folder. (issue #81) See "About" dialog for the exact path.
  * User now can select if DB transactions are enabled or not.
    (bug #70) By default, DB transactions are now switched OFF,
    therefore anyone who wants better performance, must turn
    them ON in app settings.
  * MySQL database backend now requires at least version 5.5,
    DB encoding is now changed to utf8mb4 character set. (bug
    [#74])
  * Height if message attachment image is now configurable,
    defaults to 36. (issue #69)
  * All textual contents of all messages are now locally saved
    in explicit UTF-8 encoding. This is partially because of
    MySQL backend. We need to keep encoding of data sent to DB
    and encoding of DB itself in parity.
  Changed:
  * TT-RSS plugin now does NOT require service URL to be
    entered with "/api/" suffix. In other words, do not use that
    suffix now, RSS Guard will add it silently when it needs to.
  Fixed:
  * Fixed problem with strings in core being rendered
    untranslated. (bug #60)
  * Fixed problem with feed updates progress bar flickering.
    (bug #73)
  * Partially fixed problem with incorrect number of
    downloaded messages being reported. (bug #70)
- Refreshed rssguard-locale.patch
* Sat Dec  3 2016 aloisio@gmx.com
- Initial package (version 3.3.5)
